@@ -34,7 +34,7 @@ AddressPoolManager& AddressPoolManager::GetInstance() {
   return singleton_;
 }
 
-#if PA_CONFIG(HAS_64_BITS_POINTERS)
+#if BUILDFLAG(HAS_64_BIT_POINTERS)
 
 namespace {
 
@@ -77,8 +77,9 @@ uintptr_t AddressPoolManager::GetPoolBaseAddress(pool_handle handle) {
 }
 
 void AddressPoolManager::ResetForTesting() {
-  for (pool_handle i = 0; i < std::size(aligned_pools_.pools_); ++i)
+  for (size_t i = 0; i < std::size(aligned_pools_.pools_); ++i) {
     aligned_pools_.pools_[i].Reset();
+  }
 }
 
 void AddressPoolManager::Remove(pool_handle handle) {
@@ -102,7 +103,7 @@ uintptr_t AddressPoolManager::Reserve(pool_handle handle,
 void AddressPoolManager::UnreserveAndDecommit(pool_handle handle,
                                               uintptr_t address,
                                               size_t length) {
-  PA_DCHECK(0 < handle && handle <= kNumPools);
+  PA_DCHECK(kNullPoolHandle < handle && handle <= kNumPools);
   Pool* pool = GetPool(handle);
   PA_DCHECK(pool->IsInitialized());
   DecommitPages(address, length);
@@ -299,7 +300,7 @@ bool AddressPoolManager::GetStats(AddressSpaceStats* stats) {
   return true;
 }
 
-#else  // PA_CONFIG(HAS_64_BITS_POINTERS)
+#else  // BUILDFLAG(HAS_64_BIT_POINTERS)
 
 static_assert(
     kSuperPageSize % AddressPoolManagerBitmap::kBytesPer1BitOfBRPPoolBitmap ==
@@ -531,7 +532,7 @@ bool AddressPoolManager::GetStats(AddressSpaceStats* stats) {
   return true;
 }
 
-#endif  // PA_CONFIG(HAS_64_BITS_POINTERS)
+#endif  // BUILDFLAG(HAS_64_BIT_POINTERS)
 
 void AddressPoolManager::DumpStats(AddressSpaceStatsDumper* dumper) {
   AddressSpaceStats stats{};
