@@ -1,4 +1,4 @@
-// Copyright (c) 2018 The Chromium Authors. All rights reserved.
+// Copyright 2018 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,7 +6,7 @@
 
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 
-namespace base {
+namespace partition_alloc {
 
 namespace {
 PartitionAllocOomCallback g_oom_callback;
@@ -24,4 +24,4 @@ void RunPartitionAllocOomCallback() {
 }
 }  // namespace internal
 
-}  // namespace base
+}  // namespace partition_alloc
