@@ -17,7 +17,6 @@
 #include "base/allocator/partition_allocator/partition_alloc_base/debug/debugging_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
-#include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
 #include "base/allocator/partition_allocator/partition_alloc_forward.h"
 #include "base/allocator/partition_allocator/partition_direct_map_extent.h"
@@ -323,23 +322,26 @@ void UnmapNow(uintptr_t reservation_start,
     // In 32-bit mode, the beginning of a reservation may be excluded from the
     // BRP pool, so shift the pointer. Other pools don't have this logic.
     PA_DCHECK(IsManagedByPartitionAllocBRPPool(
-#if PA_CONFIG(HAS_64_BITS_POINTERS)
+#if BUILDFLAG(HAS_64_BIT_POINTERS)
         reservation_start
 #else
         reservation_start +
         AddressPoolManagerBitmap::kBytesPer1BitOfBRPPoolBitmap *
             AddressPoolManagerBitmap::kGuardOffsetOfBRPPoolBitmap
-#endif
+#endif  // BUILDFLAG(HAS_64_BIT_POINTERS)
         ));
   } else
 #endif  // BUILDFLAG(ENABLE_BACKUP_REF_PTR_SUPPORT)
   {
-    PA_DCHECK(
-        pool == kRegularPoolHandle
+    PA_DCHECK(pool == kRegularPoolHandle
 #if BUILDFLAG(ENABLE_PKEYS)
-        || pool == kPkeyPoolHandle
+              || pool == kPkeyPoolHandle
 #endif
-        || (IsConfigurablePoolAvailable() && pool == kConfigurablePoolHandle));
+#if BUILDFLAG(HAS_64_BIT_POINTERS)
+              ||
+              (IsConfigurablePoolAvailable() && pool == kConfigurablePoolHandle)
+#endif
+    );
     // Non-BRP pools don't need adjustment that BRP needs in 32-bit mode.
     PA_DCHECK(IsManagedByPartitionAllocRegularPool(reservation_start) ||
 #if BUILDFLAG(ENABLE_PKEYS)
@@ -365,7 +367,7 @@ void UnmapNow(uintptr_t reservation_start,
     *offset_ptr++ = kOffsetTagNotAllocated;
   }
 
-#if !PA_CONFIG(HAS_64_BITS_POINTERS)
+#if !BUILDFLAG(HAS_64_BIT_POINTERS)
   AddressPoolManager::GetInstance().MarkUnused(pool, reservation_start,
                                                reservation_size);
 #endif
