@@ -12,14 +12,17 @@ file.
 """
 
 import collections
+import copy
 import difflib
 import inspect
 import optparse
 import os
 import sys
+import tempfile
 import unittest
 import jni_generator
 import jni_registration_generator
+import zipfile
 from jni_generator import CalledByNative
 from jni_generator import IsMainDexJavaClass
 from jni_generator import NativeMethod
@@ -44,7 +47,7 @@ def _RemoveHashedNames(natives):
   return ret
 
 
-class TestOptions(object):
+class JniGeneratorOptions(object):
   """The mock options object which is passed to the jni_generator.py script."""
 
   def __init__(self):
@@ -54,7 +57,6 @@ class TestOptions(object):
     self.ptr_type = 'long'
     self.cpp = 'cpp'
     self.javap = 'mock-javap'
-    self.native_exports_optional = True
     self.enable_profiling = False
     self.enable_tracing = False
     self.use_proxy_hash = False
@@ -65,6 +67,21 @@ class TestOptions(object):
     self.include_test_only = True
 
 
+class JniRegistrationGeneratorOptions(object):
+  """The mock options object which is passed to the jni_generator.py script."""
+
+  def __init__(self):
+    self.sources_exclusions = []
+    self.namespace = None
+    self.enable_proxy_mocks = False
+    self.require_mocks = False
+    self.use_proxy_hash = False
+    self.enable_jni_multiplexing = False
+    self.manual_jni_registration = False
+    self.include_test_only = False
+    self.header_path = None
+
+
 class BaseTest(unittest.TestCase):
 
   @staticmethod
@@ -100,10 +117,42 @@ class BaseTest(unittest.TestCase):
           signature_to_cases[signature].extend(cases)
       combined_dict[
           'FORWARDING_CALLS'] = jni_registration_generator._AddForwardingCalls(
-              signature_to_cases, namespace)
+              signature_to_cases, '')
 
     return combined_dict
 
+  def _TestEndToEndRegistration(self,
+                                input_java_src_files,
+                                options,
+                                name_to_goldens,
+                                header_golden=None):
+    with tempfile.TemporaryDirectory() as tdir:
+      options.srcjar_path = os.path.join(tdir, 'srcjar.jar')
+      if header_golden:
+        options.header_path = os.path.join(tdir, 'header.h')
+
+      input_java_paths = [
+          self._JoinScriptDir(os.path.join(_JAVA_SRC_DIR, f))
+          for f in input_java_src_files
+      ]
+
+      jni_registration_generator._Generate(options, input_java_paths)
+      with zipfile.ZipFile(options.srcjar_path, 'r') as srcjar:
+        for name in srcjar.namelist():
+          self.assertTrue(
+              name in name_to_goldens,
+              f'Found {name} output, but not present in name_to_goldens map.')
+          contents = srcjar.read(name).decode('utf-8')
+          self.AssertGoldenTextEquals(contents,
+                                      golden_file=name_to_goldens[name])
+      if header_golden:
+        with open(options.header_path, 'r') as f:
+          # Temp directory will cause some diffs each time we run if we don't
+          # normalize.
+          contents = f.read().replace(
+              tdir.replace('/', '_').upper(), 'TEMP_DIR')
+          self.AssertGoldenTextEquals(contents, golden_file=header_golden)
+
   def _JoinScriptDir(self, path):
     script_dir = os.path.dirname(sys.argv[0])
     return os.path.join(script_dir, path)
@@ -123,7 +172,7 @@ class BaseTest(unittest.TestCase):
       content = f.read()
     opts = options
     if opts is None:
-      opts = TestOptions()
+      opts = JniGeneratorOptions()
 
     jni_from_java = jni_generator.JNIFromJavaSource(content, qualified_clazz,
                                                     opts)
@@ -192,8 +241,8 @@ class BaseTest(unittest.TestCase):
     if golden_file is None:
       self.assertTrue(
           caller.startswith('test'),
-          'AssertGoldenTextEquals can only be called from a '
-          'test* method, not %s' % caller)
+          'AssertGoldenTextEquals can only be called without at golden file '
+          'from a test* method, not %s' % caller)
       golden_file = '%s%s.golden' % (caller, suffix)
     golden_text = self._ReadGoldenFile(golden_file)
     if os.environ.get(_REBASELINE_ENV):
@@ -209,6 +258,7 @@ class BaseTest(unittest.TestCase):
     self.AssertTextEquals(golden_text, generated_text)
 
 
+@unittest.skipIf(os.name == 'nt', 'Not intended to work on Windows')
 class TestGenerator(BaseTest):
 
   def testInspectCaller(self):
@@ -375,21 +425,21 @@ class TestGenerator(BaseTest):
             java_class_name=None)
     ]
     self.AssertListEquals(golden_natives, natives)
-    h1 = jni_generator.InlHeaderFileGenerator('', 'org/chromium/TestJni',
+    h1 = jni_generator.InlHeaderFileGenerator('', '', 'org/chromium/TestJni',
                                               natives, [], [], jni_params,
-                                              TestOptions())
+                                              JniGeneratorOptions())
     self.AssertGoldenTextEquals(h1.GetContent())
-    h2 = jni_registration_generator.HeaderGenerator('',
-                                                    '',
-                                                    'org/chromium/TestJni',
-                                                    natives,
-                                                    jni_params,
-                                                    True,
-                                                    use_proxy_hash=False)
+    h2 = jni_registration_generator.DictionaryGenerator(JniGeneratorOptions(),
+                                                        '', '',
+                                                        'org/chromium/TestJni',
+                                                        natives, jni_params,
+                                                        True)
     content = TestGenerator._MergeRegistrationForTests([h2.Generate()])
 
+    reg_options = JniRegistrationGeneratorOptions()
+    reg_options.manual_jni_registration = True
     self.AssertGoldenTextEquals(jni_registration_generator.CreateFromDict(
-        content, use_hash=False, manual_jni_registration=True),
+        reg_options, '', content),
                                 suffix='Registrations')
 
   def testInnerClassNatives(self):
@@ -410,9 +460,9 @@ class TestGenerator(BaseTest):
     ]
     self.AssertListEquals(golden_natives, natives)
     jni_params = jni_generator.JniParams('')
-    h = jni_generator.InlHeaderFileGenerator('', 'org/chromium/TestJni',
+    h = jni_generator.InlHeaderFileGenerator('', '', 'org/chromium/TestJni',
                                              natives, [], [], jni_params,
-                                             TestOptions())
+                                             JniGeneratorOptions())
     self.AssertGoldenTextEquals(h.GetContent())
 
   def testInnerClassNativesMultiple(self):
@@ -443,9 +493,9 @@ class TestGenerator(BaseTest):
     ]
     self.AssertListEquals(golden_natives, natives)
     jni_params = jni_generator.JniParams('')
-    h = jni_generator.InlHeaderFileGenerator('', 'org/chromium/TestJni',
+    h = jni_generator.InlHeaderFileGenerator('', '', 'org/chromium/TestJni',
                                              natives, [], [], jni_params,
-                                             TestOptions())
+                                             JniGeneratorOptions())
     self.AssertGoldenTextEquals(h.GetContent())
 
   def testInnerClassNativesBothInnerAndOuter(self):
@@ -475,22 +525,22 @@ class TestGenerator(BaseTest):
     ]
     self.AssertListEquals(golden_natives, natives)
     jni_params = jni_generator.JniParams('')
-    h = jni_generator.InlHeaderFileGenerator('', 'org/chromium/TestJni',
+    h = jni_generator.InlHeaderFileGenerator('', '', 'org/chromium/TestJni',
                                              natives, [], [], jni_params,
-                                             TestOptions())
+                                             JniGeneratorOptions())
     self.AssertGoldenTextEquals(h.GetContent())
 
-    h2 = jni_registration_generator.HeaderGenerator('',
-                                                    '',
-                                                    'org/chromium/TestJni',
-                                                    natives,
-                                                    jni_params,
-                                                    True,
-                                                    use_proxy_hash=False)
+    h2 = jni_registration_generator.DictionaryGenerator(JniGeneratorOptions(),
+                                                        '', '',
+                                                        'org/chromium/TestJni',
+                                                        natives, jni_params,
+                                                        True)
     content = TestGenerator._MergeRegistrationForTests([h2.Generate()])
 
+    reg_options = JniRegistrationGeneratorOptions()
+    reg_options.manual_jni_registration = True
     self.AssertGoldenTextEquals(jni_registration_generator.CreateFromDict(
-        content, use_hash=False, manual_jni_registration=True),
+        reg_options, '', content),
                                 suffix='Registrations')
 
   def testCalledByNatives(self):
@@ -839,9 +889,9 @@ class TestGenerator(BaseTest):
         ),
     ]
     self.AssertListEquals(golden_called_by_natives, called_by_natives)
-    h = jni_generator.InlHeaderFileGenerator('', 'org/chromium/TestJni', [],
+    h = jni_generator.InlHeaderFileGenerator('', '', 'org/chromium/TestJni', [],
                                              called_by_natives, [], jni_params,
-                                             TestOptions())
+                                             JniGeneratorOptions())
     self.AssertGoldenTextEquals(h.GetContent())
 
   def testCalledByNativeParseError(self):
@@ -938,8 +988,8 @@ public abstract class java.util.HashSet<T> extends java.util.AbstractSet<E>
       Signature: ([Landroid/icu/text/DisplayContext;)V
 }
 """
-    jni_from_javap = jni_generator.JNIFromJavaP(
-        contents.split('\n'), TestOptions())
+    jni_from_javap = jni_generator.JNIFromJavaP(contents.split('\n'),
+                                                JniGeneratorOptions())
     self.AssertGoldenTextEquals(jni_from_javap.GetContent())
 
   def testSnippnetJavap6_7_8(self):
@@ -964,12 +1014,12 @@ public class java.util.HashSet {
 }
 """
 
-    jni_from_javap6 = jni_generator.JNIFromJavaP(
-        content_javap6.split('\n'), TestOptions())
-    jni_from_javap7 = jni_generator.JNIFromJavaP(
-        content_javap7.split('\n'), TestOptions())
-    jni_from_javap8 = jni_generator.JNIFromJavaP(
-        content_javap8.split('\n'), TestOptions())
+    jni_from_javap6 = jni_generator.JNIFromJavaP(content_javap6.split('\n'),
+                                                 JniGeneratorOptions())
+    jni_from_javap7 = jni_generator.JNIFromJavaP(content_javap7.split('\n'),
+                                                 JniGeneratorOptions())
+    jni_from_javap8 = jni_generator.JNIFromJavaP(content_javap8.split('\n'),
+                                                 JniGeneratorOptions())
     self.assertTrue(jni_from_javap6.GetContent())
     self.assertTrue(jni_from_javap7.GetContent())
     self.assertTrue(jni_from_javap8.GetContent())
@@ -983,16 +1033,16 @@ public class java.util.HashSet {
 
   def testFromJavaP(self):
     contents = self._ReadGoldenFile('testInputStream.javap')
-    jni_from_javap = jni_generator.JNIFromJavaP(
-        contents.split('\n'), TestOptions())
+    jni_from_javap = jni_generator.JNIFromJavaP(contents.split('\n'),
+                                                JniGeneratorOptions())
     self.assertEqual(10, len(jni_from_javap.called_by_natives))
     self.AssertGoldenTextEquals(jni_from_javap.GetContent())
 
   def testConstantsFromJavaP(self):
     for f in ['testMotionEvent.javap', 'testMotionEvent.javap7']:
       contents = self._ReadGoldenFile(f)
-      jni_from_javap = jni_generator.JNIFromJavaP(
-          contents.split('\n'), TestOptions())
+      jni_from_javap = jni_generator.JNIFromJavaP(contents.split('\n'),
+                                                  JniGeneratorOptions())
       self.assertEqual(86, len(jni_from_javap.called_by_natives))
       self.AssertGoldenTextEquals(jni_from_javap.GetContent())
 
@@ -1013,8 +1063,8 @@ public class java.util.HashSet {
     private native void nativeSyncSetupEnded(
         int nativeAndroidSyncSetupFlowHandler);
     """
-    jni_from_java = jni_generator.JNIFromJavaSource(
-        test_data, 'foo/bar', TestOptions())
+    jni_from_java = jni_generator.JNIFromJavaSource(test_data, 'foo/bar',
+                                                    JniGeneratorOptions())
     self.AssertGoldenTextEquals(jni_from_java.GetContent())
 
   def testRaisesOnNonJNIMethod(self):
@@ -1025,7 +1075,7 @@ public class java.util.HashSet {
     }
     """
     self.assertRaises(SyntaxError, jni_generator.JNIFromJavaSource, test_data,
-                      'foo/bar', TestOptions())
+                      'foo/bar', JniGeneratorOptions())
 
   def testJniSelfDocumentingExample(self):
     generated_text = self._CreateJniHeaderFromFile(
@@ -1045,7 +1095,7 @@ public class java.util.HashSet {
     jni_from_java = jni_generator.JNIFromJavaSource(
         test_data, ('com/google/lookhowextremelylongiam/snarf/'
                     'icankeepthisupallday/ReallyLongClassNamesAreAllTheRage'),
-        TestOptions())
+        JniGeneratorOptions())
     jni_lines = jni_from_java.GetContent().split('\n')
     line = next(
         line for line in jni_lines if line.lstrip().startswith('#ifndef'))
@@ -1113,7 +1163,7 @@ class Foo {
                           jni_params.JavaToJni('java/nio/ByteBuffer[]'))
 
   def testNativesLong(self):
-    test_options = TestOptions()
+    test_options = JniGeneratorOptions()
     test_options.ptr_type = 'long'
     test_data = """"
     private native void nativeDestroy(long nativeChromeBrowserProvider);
@@ -1131,8 +1181,9 @@ class Foo {
             ptr_type=test_options.ptr_type),
     ]
     self.AssertListEquals(golden_natives, natives)
-    h = jni_generator.InlHeaderFileGenerator(
-        '', 'org/chromium/TestJni', natives, [], [], jni_params, test_options)
+    h = jni_generator.InlHeaderFileGenerator('', '', 'org/chromium/TestJni',
+                                             natives, [], [], jni_params,
+                                             test_options)
     self.AssertGoldenTextEquals(h.GetContent())
 
   def testMainDexAnnotation(self):
@@ -1210,8 +1261,7 @@ class Foo {
         }
     }
     """
-    options = TestOptions()
-    options.native_exports_optional = False
+    options = JniGeneratorOptions()
     jni_from_java = jni_generator.JNIFromJavaSource(
         test_data, 'org/chromium/example/jni_generator/SampleForTests', options)
     self.AssertGoldenTextEquals(jni_from_java.GetContent())
@@ -1229,7 +1279,7 @@ class Foo {
     def willRaise():
       jni_generator.JNIFromJavaSource(test_data,
                                       'org/chromium/media/VideoCaptureFactory',
-                                      TestOptions())
+                                      JniGeneratorOptions())
 
     self.assertRaises(SyntaxError, willRaise)
 
@@ -1249,7 +1299,7 @@ class Foo {
     """
     jni_from_java = jni_generator.JNIFromJavaSource(test_data,
                                                     'org/chromium/foo/Foo',
-                                                    TestOptions())
+                                                    JniGeneratorOptions())
     self.AssertGoldenTextEquals(jni_from_java.GetContent())
 
   def testMultipleJNIAdditionalImport(self):
@@ -1270,7 +1320,7 @@ class Foo {
     """
     jni_from_java = jni_generator.JNIFromJavaSource(test_data,
                                                     'org/chromium/foo/Foo',
-                                                    TestOptions())
+                                                    JniGeneratorOptions())
     self.AssertGoldenTextEquals(jni_from_java.GetContent())
 
   def testTracing(self):
@@ -1291,7 +1341,7 @@ class Foo {
     static native void nativeStaticMethod();
     }
     """
-    options_with_tracing = TestOptions()
+    options_with_tracing = JniGeneratorOptions()
     options_with_tracing.enable_tracing = True
     jni_from_java = jni_generator.JNIFromJavaSource(
         test_data, 'org/chromium/foo/Foo', options_with_tracing)
@@ -1314,11 +1364,11 @@ class Foo {
 
     jni_from_java = jni_generator.JNIFromJavaSource(test_data,
                                                     'org/chromium/foo/Foo',
-                                                    TestOptions())
+                                                    JniGeneratorOptions())
     self.AssertGoldenTextEquals(jni_from_java.GetContent())
 
   def testSplitNameExample(self):
-    opts = TestOptions()
+    opts = JniGeneratorOptions()
     opts.split_name = "sample"
     generated_text = self._CreateJniHeaderFromFile(
         os.path.join(_JAVA_SRC_DIR, 'SampleForTests.java'),
@@ -1327,19 +1377,58 @@ class Foo {
         generated_text, golden_file='SampleForTestsWithSplit_jni.golden')
 
 
+@unittest.skipIf(os.name == 'nt', 'Not intended to work on Windows')
 class ProxyTestGenerator(BaseTest):
 
-  def _BuildRegDictFromSample(self, options=None):
-    if options is None:
-      options = TestOptions()
-
+  def _BuildRegDictFromSample(self):
     path = self._JoinScriptDir(
         os.path.join(_JAVA_SRC_DIR, 'SampleForAnnotationProcessor.java'))
-    reg_dict = jni_registration_generator._DictForPath(path)
+    reg_dict = jni_registration_generator._DictForPath(
+        JniRegistrationGeneratorOptions(), path)
     reg_dict = self._MergeRegistrationForTests([reg_dict])
 
     return reg_dict
 
+  def testEndToEndProxyHashed(self):
+    input_java_files = ['SampleForAnnotationProcessor.java']
+    options = JniRegistrationGeneratorOptions()
+    options.use_proxy_hash = True
+    name_to_goldens = {
+        'org/chromium/base/natives/GEN_JNI.java':
+        'HashedSampleForAnnotationProcessorGenJni.2.golden',
+        'J/N.java': 'HashedSampleForAnnotationProcessorGenJni.golden'
+    }
+    self._TestEndToEndRegistration(input_java_files, options, name_to_goldens)
+
+  def testEndToEndManualRegistration(self):
+    input_java_files = ['SampleForAnnotationProcessor.java']
+    options = JniRegistrationGeneratorOptions()
+    options.manual_jni_registration = True
+    name_to_goldens = {
+        'org/chromium/base/natives/GEN_JNI.java':
+        'SampleForAnnotationProcessorGenJni.golden'
+    }
+    self._TestEndToEndRegistration(
+        input_java_files,
+        options,
+        name_to_goldens,
+        header_golden='SampleForAnnotationProcessorManualJni.golden')
+
+  def testEndToEndProxyJniWithModules(self):
+    input_java_files = [
+        'SampleForAnnotationProcessor.java', 'SampleModule.java'
+    ]
+    options = JniRegistrationGeneratorOptions()
+    options.use_proxy_hash = True
+    name_to_goldens = {
+        'org/chromium/base/natives/GEN_JNI.java':
+        'HashedSampleForAnnotationProcessorGenJni.2.golden',
+        'J/N.java': 'HashedSampleForAnnotationProcessorGenJni.golden',
+        'org/chromium/base/natives/module_GEN_JNI.java': 'ModuleGenJni.golden',
+        'J/module_N.java': 'ModuleJN.golden'
+    }
+    self._TestEndToEndRegistration(input_java_files, options, name_to_goldens)
+
   def testProxyNativesWithNatives(self):
     test_data = """
     package org.chromium.foo;
@@ -1362,7 +1451,7 @@ class ProxyTestGenerator(BaseTest):
 
     }
     """
-    options_with_tracing = TestOptions()
+    options_with_tracing = JniGeneratorOptions()
     options_with_tracing.enable_tracing = True
     jni_from_java = jni_generator.JNIFromJavaSource(
         test_data, 'org/chromium/foo/Foo', options_with_tracing)
@@ -1380,7 +1469,7 @@ class ProxyTestGenerator(BaseTest):
     """
     qualified_clazz = 'org/chromium/example/SampleProxyJni'
 
-    natives = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
+    natives, _ = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
         qualified_clazz, test_data, 'long')
 
     golden_natives = [
@@ -1416,7 +1505,7 @@ class ProxyTestGenerator(BaseTest):
     """
     qualified_clazz = 'org/chromium/example/SampleProxyJni'
 
-    natives = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
+    natives, _ = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
         qualified_clazz, test_data, 'long', True)
 
     golden_natives = [
@@ -1452,7 +1541,7 @@ class ProxyTestGenerator(BaseTest):
     """
     qualified_clazz = 'org/chromium/example/SampleProxyJni'
 
-    natives = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
+    natives, _ = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
         qualified_clazz, test_data, 'long', False)
 
     self.AssertListEquals(_RemoveHashedNames(natives), [])
@@ -1481,9 +1570,10 @@ class ProxyTestGenerator(BaseTest):
     }
     """
     qualified_clazz = 'test/foo/Foo'
-    jni_params = TestOptions()
+    options = JniRegistrationGeneratorOptions()
+    options.manual_jni_registration = True
 
-    natives = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
+    natives, _ = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
         qualified_clazz, test_data, 'long')
 
     golden_natives = [
@@ -1500,42 +1590,33 @@ class ProxyTestGenerator(BaseTest):
     self.AssertListEquals(_RemoveHashedNames(natives), golden_natives)
 
     jni_params = jni_generator.JniParams(qualified_clazz)
-    main_dex_header = jni_registration_generator.HeaderGenerator(
-        '',
-        '',
-        qualified_clazz,
-        natives,
-        jni_params,
-        main_dex=True,
-        use_proxy_hash=False).Generate()
+    main_dex_header = jni_registration_generator.DictionaryGenerator(
+        options, '', '', qualified_clazz, natives, jni_params,
+        main_dex=True).Generate()
     content = TestGenerator._MergeRegistrationForTests([main_dex_header])
 
     self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateFromDict(content,
-                                                  use_hash=False,
-                                                  manual_jni_registration=True))
+        jni_registration_generator.CreateFromDict(options, '', content))
 
     other_qualified_clazz = 'test/foo/Bar'
-    other_natives = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
+    other_natives, _ = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
         other_qualified_clazz, non_main_dex_test_data, 'long')
 
     jni_params = jni_generator.JniParams(other_qualified_clazz)
-    non_main_dex_header = jni_registration_generator.HeaderGenerator(
+    non_main_dex_header = jni_registration_generator.DictionaryGenerator(
+        options,
         '',
         '',
         other_qualified_clazz,
         other_natives,
         jni_params,
-        main_dex=False,
-        use_proxy_hash=False).Generate()
+        main_dex=False).Generate()
 
     content = TestGenerator._MergeRegistrationForTests([main_dex_header] +
                                                        [non_main_dex_header])
 
     self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateFromDict(content,
-                                                  use_hash=False,
-                                                  manual_jni_registration=True),
+        jni_registration_generator.CreateFromDict(options, '', content),
         'AndNonMainDex')
 
   def testProxyNatives(self):
@@ -1575,9 +1656,9 @@ class ProxyTestGenerator(BaseTest):
 
     qualified_clazz = 'org/chromium/example/SampleProxyJni'
 
-    natives = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
+    natives, _ = jni_generator.ProxyHelpers.ExtractStaticProxyNatives(
         qualified_clazz, test_data, 'long')
-    bad_spacing_natives = jni_generator.ProxyHelpers \
+    bad_spacing_natives, _ = jni_generator.ProxyHelpers \
       .ExtractStaticProxyNatives(qualified_clazz, bad_spaced_test_data, 'long')
     golden_natives = [
         NativeMethod(
@@ -1616,34 +1697,32 @@ class ProxyTestGenerator(BaseTest):
     self.AssertListEquals(golden_natives, _RemoveHashedNames(natives))
     self.AssertListEquals(golden_natives,
                           _RemoveHashedNames(bad_spacing_natives))
+    options = JniGeneratorOptions()
+    reg_options = JniRegistrationGeneratorOptions()
+    reg_options.manual_jni_registration = True
 
     jni_params = jni_generator.JniParams(qualified_clazz)
-    h1 = jni_generator.InlHeaderFileGenerator('', qualified_clazz, natives, [],
-                                              [], jni_params, TestOptions())
+    h1 = jni_generator.InlHeaderFileGenerator('', '', qualified_clazz, natives,
+                                              [], [], jni_params, options)
     self.AssertGoldenTextEquals(h1.GetContent())
-    h2 = jni_registration_generator.HeaderGenerator('',
-                                                    '',
-                                                    qualified_clazz,
-                                                    natives,
-                                                    jni_params,
-                                                    False,
-                                                    use_proxy_hash=False)
+    h2 = jni_registration_generator.DictionaryGenerator(reg_options, '', '',
+                                                        qualified_clazz,
+                                                        natives, jni_params,
+                                                        False)
     content = TestGenerator._MergeRegistrationForTests([h2.Generate()])
 
-    proxy_opts = jni_registration_generator.ProxyOptions(
-        manual_jni_registration=True)
+
     self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateProxyJavaFromDict(content, proxy_opts),
+        jni_registration_generator.CreateProxyJavaFromDict(
+            reg_options, '', content),
         suffix='Java')
 
     self.AssertGoldenTextEquals(jni_registration_generator.CreateFromDict(
-        content,
-        proxy_opts.use_hash,
-        manual_jni_registration=proxy_opts.manual_jni_registration),
+        reg_options, '', content),
                                 suffix='Registrations')
 
   def testProxyHashedExample(self):
-    opts = TestOptions()
+    opts = JniGeneratorOptions()
     opts.use_proxy_hash = True
     path = os.path.join(_JAVA_SRC_DIR, 'SampleForAnnotationProcessor.java')
 
@@ -1654,20 +1733,6 @@ class ProxyTestGenerator(BaseTest):
         generated_text,
         golden_file='HashedSampleForAnnotationProcessor_jni.golden')
 
-    reg_dict = jni_registration_generator._DictForPath(
-        self._JoinScriptDir(path), use_proxy_hash=True)
-    reg_dict = self._MergeRegistrationForTests([reg_dict])
-
-    proxy_opts = jni_registration_generator.ProxyOptions(use_hash=True)
-    self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateProxyJavaFromDict(
-            reg_dict, proxy_opts),
-        golden_file='HashedSampleForAnnotationProcessorGenJni.golden')
-    self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateProxyJavaFromDict(
-            reg_dict, proxy_opts, forwarding=True),
-        golden_file='HashedSampleForAnnotationProcessorGenJni.2.golden')
-
   def testProxyJniExample(self):
     generated_text = self._CreateJniHeaderFromFile(
         os.path.join(_JAVA_SRC_DIR, 'SampleForAnnotationProcessor.java'),
@@ -1676,21 +1741,20 @@ class ProxyTestGenerator(BaseTest):
         generated_text, golden_file='SampleForAnnotationProcessor_jni.golden')
 
   def testGenJniFlags(self):
+    options = JniRegistrationGeneratorOptions()
     reg_dict = self._BuildRegDictFromSample()
-    proxy_options = jni_registration_generator.ProxyOptions()
     content = jni_registration_generator.CreateProxyJavaFromDict(
-        reg_dict, proxy_options)
+        options, '', reg_dict)
     self.AssertGoldenTextEquals(content, 'Disabled')
 
-    proxy_options = jni_registration_generator.ProxyOptions(enable_mocks=True)
+    options.enable_proxy_mocks = True
     content = jni_registration_generator.CreateProxyJavaFromDict(
-        reg_dict, proxy_options)
+        options, '', reg_dict)
     self.AssertGoldenTextEquals(content, 'MocksEnabled')
 
-    proxy_options = jni_registration_generator.ProxyOptions(
-        enable_mocks=True, require_mocks=True)
+    options.require_mocks = True
     content = jni_registration_generator.CreateProxyJavaFromDict(
-        reg_dict, proxy_options)
+        options, '', reg_dict)
     self.AssertGoldenTextEquals(content, 'MocksRequired')
 
   def testProxyTypeInfoPreserved(self):
@@ -1708,8 +1772,8 @@ class ProxyTestGenerator(BaseTest):
           SomeJavaType[][] someObjects);
     }
     """
-    natives = ProxyHelpers.ExtractStaticProxyNatives('org/chromium/foo/FooJni',
-                                                     test_data, 'long')
+    natives, _ = ProxyHelpers.ExtractStaticProxyNatives(
+        'org/chromium/foo/FooJni', test_data, 'long')
     golden_natives = [
         NativeMethod(
             static=True,
@@ -1758,63 +1822,53 @@ class ProxyTestGenerator(BaseTest):
     self.AssertListEquals(golden_natives, _RemoveHashedNames(natives))
 
 
+@unittest.skipIf(os.name == 'nt', 'Not intended to work on Windows')
 class MultiplexTestGenerator(BaseTest):
+  options = JniRegistrationGeneratorOptions()
+  options.enable_jni_multiplexing = True
+
   def testProxyMultiplexGenJni(self):
     path = os.path.join(_JAVA_SRC_DIR, 'SampleForAnnotationProcessor.java')
     reg_dict = jni_registration_generator._DictForPath(
-        self._JoinScriptDir(path),
-        enable_jni_multiplexing=True,
-        namespace='test')
+        self.options, self._JoinScriptDir(path))
     reg_dict = self._MergeRegistrationForTests([reg_dict],
                                                enable_jni_multiplexing=True)
 
-    proxy_opts = jni_registration_generator.ProxyOptions(
-        enable_jni_multiplexing=True)
     self.AssertGoldenTextEquals(
         jni_registration_generator.CreateProxyJavaFromDict(
-            reg_dict, proxy_opts),
+            self.options, '', reg_dict),
         golden_file='testProxyMultiplexGenJni.golden')
 
     self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateProxyJavaFromDict(reg_dict,
-                                                           proxy_opts,
+        jni_registration_generator.CreateProxyJavaFromDict(self.options,
+                                                           '',
+                                                           reg_dict,
                                                            forwarding=True),
         golden_file='testProxyMultiplexGenJni.2.golden')
 
   def testProxyMultiplexNatives(self):
     path = os.path.join(_JAVA_SRC_DIR, 'SampleForAnnotationProcessor.java')
     reg_dict = jni_registration_generator._DictForPath(
-        self._JoinScriptDir(path),
-        enable_jni_multiplexing=True,
-        namespace='test')
+        self.options, self._JoinScriptDir(path))
     reg_dict = self._MergeRegistrationForTests([reg_dict],
                                                enable_jni_multiplexing=True)
 
-    proxy_opts = jni_registration_generator.ProxyOptions(
-        enable_jni_multiplexing=True)
     self.AssertGoldenTextEquals(jni_registration_generator.CreateFromDict(
-        reg_dict,
-        proxy_opts.use_hash,
-        enable_jni_multiplexing=proxy_opts.enable_jni_multiplexing),
+        self.options, '', reg_dict),
                                 golden_file='testProxyMultiplexNatives.golden')
 
   def testProxyMultiplexNativesRegistration(self):
     path = os.path.join(_JAVA_SRC_DIR, 'SampleForAnnotationProcessor.java')
     reg_dict_for_registration = jni_registration_generator._DictForPath(
-        self._JoinScriptDir(path),
-        enable_jni_multiplexing=True,
-        namespace='test')
+        self.options, self._JoinScriptDir(path))
     reg_dict_for_registration = self._MergeRegistrationForTests(
         [reg_dict_for_registration], enable_jni_multiplexing=True)
 
-    proxy_opts = jni_registration_generator.ProxyOptions(
-        enable_jni_multiplexing=True)
+    new_options = copy.copy(self.options)
+    new_options.manual_jni_registration = True
     self.AssertGoldenTextEquals(
-        jni_registration_generator.CreateFromDict(
-            reg_dict_for_registration,
-            proxy_opts.use_hash,
-            enable_jni_multiplexing=proxy_opts.enable_jni_multiplexing,
-            manual_jni_registration=True),
+        jni_registration_generator.CreateFromDict(new_options, '',
+                                                  reg_dict_for_registration),
         golden_file='testProxyMultiplexNativesRegistration.golden')
 
 
