@@ -20,6 +20,7 @@
 #include "base/debug/crash_logging.h"
 #include "base/immediate_crash.h"
 #include "base/pending_task.h"
+#include "base/process/process_handle.h"
 #include "base/strings/string_piece.h"
 #include "base/task/common/task_annotator.h"
 #include "base/trace_event/base_tracing.h"
@@ -86,14 +87,13 @@ typedef FILE* FileHandle;
 #include <utility>
 
 #include "base/base_switches.h"
-#include "base/callback.h"
 #include "base/command_line.h"
 #include "base/containers/stack.h"
-#include "base/debug/activity_tracker.h"
 #include "base/debug/alias.h"
 #include "base/debug/debugger.h"
 #include "base/debug/stack_trace.h"
 #include "base/debug/task_trace.h"
+#include "base/functional/callback.h"
 #include "base/no_destructor.h"
 #include "base/path_service.h"
 #include "base/posix/eintr_wrapper.h"
@@ -510,6 +510,18 @@ std::string BuildCrashString(const char* file,
   return base::StringPrintf("%s:%d: %s", file, line, message_without_prefix);
 }
 
+// Invokes macro to record trace event when a log message is emitted.
+void traceLogMessage(const char* file, int line, const std::string& message) {
+  TRACE_EVENT_INSTANT("log", "LogMessage", [&](perfetto::EventContext ctx) {
+    perfetto::protos::pbzero::LogMessage* log = ctx.event()->set_log_message();
+    log->set_source_location_iid(base::trace_event::InternedSourceLocation::Get(
+        &ctx, base::trace_event::TraceSourceLocation(/*function_name=*/nullptr,
+                                                     file, line)));
+    log->set_body_iid(
+        base::trace_event::InternedLogMessage::Get(&ctx, message));
+  });
+}
+
 }  // namespace
 
 #if BUILDFLAG(DCHECK_IS_CONFIGURABLE)
@@ -736,8 +748,9 @@ LogMessage::~LogMessage() {
 #endif
   stream_ << std::endl;
   std::string str_newline(stream_.str());
-  TRACE_LOG_MESSAGE(
-      file_, base::StringPiece(str_newline).substr(message_start_), line_);
+  traceLogMessage(
+      file_, line_,
+      std::string(base::StringPiece(str_newline).substr(message_start_)));
 
   if (severity_ == LOGGING_FATAL)
     SetLogFatalCrashKey(this);
@@ -920,12 +933,6 @@ LogMessage::~LogMessage() {
   }
 
   if (severity_ == LOGGING_FATAL) {
-    // Write the log message to the global activity tracker, if running.
-    base::debug::GlobalActivityTracker* tracker =
-        base::debug::GlobalActivityTracker::Get();
-    if (tracker)
-      tracker->RecordLogMessage(str_newline);
-
     char str_stack[1024];
     base::strlcpy(str_stack, str_newline.data(), std::size(str_stack));
     base::debug::Alias(&str_stack);
