@@ -193,10 +193,7 @@ class BASE_EXPORT ThreadController {
   // switching MainThreadOnly to thread annotations and annotating all
   // thread-affine ThreadController methods. Without that, this lone annotation
   // would result in an inconsistent set of DCHECKs...
-  //
-  // TODO(crbug.com/1298696): foo_unittests breaks with MTECheckedPtr
-  // enabled. Triage.
-  raw_ptr<const TickClock, DegradeToNoOpWhenMTE> time_source_;  // Not owned.
+  raw_ptr<const TickClock> time_source_;  // Not owned.
 
   // Tracks the state of each run-level (main and nested ones) in its associated
   // ThreadController. It does so using two high-level principles:
@@ -272,9 +269,13 @@ class BASE_EXPORT ThreadController {
       return run_levels_.size();
     }
 
+    // Emits a perfetto::Flow (wakeup.flow) event associated with this
+    // RunLevelTracker.
+    void RecordScheduleWork();
+
     void EnableTimeKeeperMetrics(const char* thread_name);
 
-    // Observers changes of state sent as trace-events so they can be tested.
+    // Observes changes of state sent as trace-events so they can be tested.
     class TraceObserverForTesting {
      public:
       virtual ~TraceObserverForTesting() = default;
@@ -288,6 +289,12 @@ class BASE_EXPORT ThreadController {
         TraceObserverForTesting* trace_observer_for_testing);
 
    private:
+#if BUILDFLAG(ENABLE_BASE_TRACING)
+    using TerminatingFlowLambda =
+        std::invoke_result<decltype(perfetto::TerminatingFlow::FromPointer),
+                           void*>::type;
+#endif
+
     // Keeps track of the time spent in various Phases (ignores idle), reports
     // via UMA to the corresponding phase every time one reaches >= 100ms of
     // cumulative time, resulting in a metric of relative time spent in each
@@ -372,7 +379,12 @@ class BASE_EXPORT ThreadController {
       RunLevel(State initial_state,
                bool is_nested,
                TimeKeeper& time_keeper,
-               LazyNow& lazy_now);
+               LazyNow& lazy_now
+#if BUILDFLAG(ENABLE_BASE_TRACING)
+               ,
+               TerminatingFlowLambda& terminating_flow_lambda
+#endif
+      );
       ~RunLevel();
 
       // Move-constructible for STL compat. Flags `other.was_moved_` so it noops
@@ -401,6 +413,9 @@ class BASE_EXPORT ThreadController {
 
       SampleMetadata thread_controller_sample_metadata_;
       size_t thread_controller_active_id_ = 0;
+#if BUILDFLAG(ENABLE_BASE_TRACING)
+      const raw_ref<TerminatingFlowLambda> terminating_wakeup_flow_lambda_;
+#endif
 
       // Toggles to true when used as RunLevel&& input to construct another
       // RunLevel. This RunLevel's destructor will then no-op.
@@ -421,6 +436,11 @@ class BASE_EXPORT ThreadController {
 
     [[maybe_unused]] const raw_ref<const ThreadController> outer_;
 
+#if BUILDFLAG(ENABLE_BASE_TRACING)
+    TerminatingFlowLambda terminating_wakeup_lambda_{
+        perfetto::TerminatingFlow::FromPointer(this)};
+#endif
+
     std::stack<RunLevel, std::vector<RunLevel>> run_levels_
         GUARDED_BY_CONTEXT(outer_->associated_thread_->thread_checker);
 
