@@ -8,7 +8,7 @@
 #include <memory>
 
 #include "base/base_export.h"
-#include "base/callback.h"
+#include "base/functional/callback.h"
 #include "base/task/delay_policy.h"
 #include "base/task/delayed_task_handle.h"
 #include "base/task/sequenced_task_runner_helpers.h"
@@ -181,10 +181,10 @@ class BASE_EXPORT SequencedTaskRunner : public TaskRunner {
   // directly. Consider using higher level timer primitives in
   // base/timer/timer.h.
   //
-  // The handle is only valid while the task is pending execution. This means
-  // that it will be invalid if the posting failed, and will be invalid while
-  // the task is executing. Calling CancelTask() on an invalid handle is a
-  // no-op.
+  // The handle is only guaranteed valid while the task is pending execution.
+  // This means that it may be invalid if the posting failed, and will be
+  // invalid while the task is executing. Calling CancelTask() on an invalid
+  // handle is a no-op.
   //
   // This method and the handle it returns are not thread-safe and can only be
   // used from the sequence this task runner runs its tasks on.
@@ -221,6 +221,10 @@ class BASE_EXPORT SequencedTaskRunner : public TaskRunner {
   // Submits a non-nestable task to delete the given object.  Returns
   // true if the object may be deleted at some point in the future,
   // and false if the object definitely will not be deleted.
+  //
+  // By default, this leaks `object` if the deleter task doesn't run, e.g. if
+  // the underlying task queue is shut down first. Subclasses can override this
+  // behavior by specializing `DeleteOrReleaseSoonInternal()`.
   template <class T>
   bool DeleteSoon(const Location& from_here, const T* object) {
     return DeleteOrReleaseSoonInternal(from_here, &DeleteHelper<T>::DoDelete,
@@ -235,6 +239,10 @@ class BASE_EXPORT SequencedTaskRunner : public TaskRunner {
 
   // Submits a non-nestable task to release the given object.
   //
+  // By default, this leaks `object` if the releaser task doesn't run, e.g. if
+  // the underlying task queue is shut down first. Subclasses can override this
+  // behavior by specializing `DeleteOrReleaseSoonInternal()`.
+  //
   // ReleaseSoon makes sure that the object it the scoped_refptr points to gets
   // properly released on the correct thread.
   // We apply ReleaseSoon to the rvalue as the side-effects can be unclear to
@@ -320,10 +328,9 @@ class BASE_EXPORT SequencedTaskRunner : public TaskRunner {
     current_default.task_runner_ = task_runner;
   }
 
- private:
-  bool DeleteOrReleaseSoonInternal(const Location& from_here,
-                                   void (*deleter)(const void*),
-                                   const void* object);
+  virtual bool DeleteOrReleaseSoonInternal(const Location& from_here,
+                                           void (*deleter)(const void*),
+                                           const void* object);
 };
 
 // Sample usage with std::unique_ptr :
