@@ -174,8 +174,13 @@ void ThreadGroup::ReEnqueueTaskSourceLockRequired(
     } else {
       // If the TaskSource should be reenqueued in the current thread group,
       // reenqueue it inside the scope of the lock.
-      auto sort_key = transaction_with_task_source.task_source->GetSortKey();
       if (push_to_immediate_queue) {
+        auto sort_key = transaction_with_task_source.task_source->GetSortKey();
+        // When moving |task_source| into |priority_queue_|, it may be destroyed
+        // on another thread as soon as |lock_| is released, since we're no
+        // longer holding a reference to it. To prevent UAF, release
+        // |transaction| before moving |task_source|. Ref. crbug.com/1412008
+        transaction_with_task_source.transaction.Release();
         priority_queue_.Push(
             std::move(transaction_with_task_source.task_source), sort_key);
       }
@@ -250,6 +255,11 @@ void ThreadGroup::PushTaskSourceAndWakeUpWorkersImpl(
     return;
   }
   auto sort_key = transaction_with_task_source.task_source->GetSortKey();
+  // When moving |task_source| into |priority_queue_|, it may be destroyed
+  // on another thread as soon as |lock_| is released, since we're no longer
+  // holding a reference to it. To prevent UAF, release |transaction| before
+  // moving |task_source|. Ref. crbug.com/1412008
+  transaction_with_task_source.transaction.Release();
   priority_queue_.Push(std::move(transaction_with_task_source.task_source),
                        sort_key);
   EnsureEnoughWorkersLockRequired(executor);
