@@ -31,12 +31,17 @@
 #include "build/build_config.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
 
+#if BUILDFLAG(USE_PERFETTO_CLIENT_LIBRARY)
+#include "third_party/perfetto/include/perfetto/tracing/core/trace_config.h"
+
 namespace perfetto {
 namespace trace_processor {
 class TraceProcessorStorage;
 }  // namespace trace_processor
 }  // namespace perfetto
 
+#endif  // BUILDFLAG(USE_PERFETTO_CLIENT_LIBRARY)
+
 namespace base {
 class RefCountedString;
 
@@ -110,9 +115,9 @@ class BASE_EXPORT TraceLog :
     // In SDK build we return true as soon as the datasource has been set up and
     // we know the config. This doesn't necessarily mean that the tracing has
     // already started.
-    // Note that perfetto::TrackEvent::IsEnabled() can be true even earlier,
-    // before the OnSetup call, so we can't guarantee that we know the config
-    // by the time perfetto::TrackEvent::IsEnabled() is true.
+    // Note that TrackEvent::IsEnabled() can be true even earlier, before the
+    // OnSetup call, so we can't guarantee that we know the config by the time
+    // TrackEvent::IsEnabled() is true.
     AutoLock lock(track_event_lock_);
     return track_event_enabled_;
 #else   // !BUILDFLAG(USE_PERFETTO_CLIENT_LIBRARY)
