@@ -4,8 +4,8 @@
 
 #include "crypto/unexportable_key.h"
 
-#include "base/bind.h"
 #include "base/check.h"
+#include "base/functional/bind.h"
 #include "build/build_config.h"
 
 namespace crypto {
