@@ -87,6 +87,10 @@ NET_EXPORT extern const base::FeatureParam<base::TimeDelta>
 // Update protocol using ALPN information in HTTPS DNS records.
 NET_EXPORT BASE_DECLARE_FEATURE(kUseDnsHttpsSvcbAlpn);
 
+// If enabled allows the use of SHA-1 by the server for signatures
+// in the TLS handshake.
+NET_EXPORT BASE_DECLARE_FEATURE(kSHA1ServerSignature);
+
 // Enables TLS 1.3 early data.
 NET_EXPORT BASE_DECLARE_FEATURE(kEnableTLS13EarlyData);
 
@@ -114,11 +118,6 @@ NET_EXPORT BASE_DECLARE_FEATURE(kSplitHostCacheByNetworkIsolationKey);
 // request.
 NET_EXPORT BASE_DECLARE_FEATURE(kPartitionConnectionsByNetworkIsolationKey);
 
-// Forces the `frame_origin` value in IsolationInfo to the `top_level_origin`
-// value when an IsolationInfo instance is created. This is to enable
-// expirimenting with double keyed network partitions.
-NET_EXPORT BASE_DECLARE_FEATURE(kForceIsolationInfoFrameOriginToTopLevelFrame);
-
 // Partitions HttpServerProperties based on the NetworkIsolationKey associated
 // with a request.
 NET_EXPORT BASE_DECLARE_FEATURE(
@@ -148,17 +147,9 @@ NET_EXPORT BASE_DECLARE_FEATURE(kPartitionNelAndReportingByNetworkIsolationKey);
 // `frame_site ` -> nullopt
 // `is_cross_site` -> true if the `top_frame_site` is cross site when compared
 // to the frame site. The frame site will not be stored in this key so the value
-// of is_cross_site will be computed at key construction. This feature overrides
-// `kEnableDoubleKeyNetworkAnonymizationKey` if both are enabled.
+// of is_cross_site will be computed at key construction.
 NET_EXPORT BASE_DECLARE_FEATURE(kEnableCrossSiteFlagNetworkAnonymizationKey);
 
-// Creates a double keyed NetworkAnonymizationKey which is used to partition the
-// network state. This double key will have the following properties:
-// `top_frame_site` -> the schemeful site of the top level page.
-// `frame_site ` -> nullopt
-// `is_cross_site` -> nullopt
-NET_EXPORT BASE_DECLARE_FEATURE(kEnableDoubleKeyNetworkAnonymizationKey);
-
 // Enables sending TLS 1.3 Key Update messages on TLS 1.3 connections in order
 // to ensure that this corner of the spec is exercised. This is currently
 // disabled by default because we discovered incompatibilities with some
@@ -184,9 +175,6 @@ NET_EXPORT BASE_DECLARE_FEATURE(kPostQuantumCECPQ2SomeDomains);
 NET_EXPORT extern const base::FeatureParam<std::string>
     kPostQuantumCECPQ2Prefix;
 
-// Causes SSLClientSocket to force a minimum TLS version of at least TLS 1.2.
-NET_EXPORT BASE_DECLARE_FEATURE(kSSLMinVersionAtLeastTLS12);
-
 // Changes the timeout after which unused sockets idle sockets are cleaned up.
 NET_EXPORT BASE_DECLARE_FEATURE(kNetUnusedIdleSocketTimeout);
 
@@ -333,29 +321,6 @@ NET_EXPORT BASE_DECLARE_FEATURE(kBlockSetCookieHeader);
 
 NET_EXPORT BASE_DECLARE_FEATURE(kOptimisticBlockfileWrite);
 
-// Enable the Storage Access API. https://crbug.com/989663.
-NET_EXPORT BASE_DECLARE_FEATURE(kStorageAccessAPI);
-
-// Set the default number of "automatic" implicit storage access grants per
-// third party origin that can be granted. This can be overridden via
-// experimentation to allow for field trials to validate the default setting.
-NET_EXPORT extern const int kStorageAccessAPIDefaultImplicitGrantLimit;
-NET_EXPORT extern const base::FeatureParam<int>
-    kStorageAccessAPIImplicitGrantLimit;
-// Whether the Storage Access API can grant access to storage (even if it is
-// unpartitioned). When this feature is disabled, access to storage is only
-// granted if the storage is partitioned.
-NET_EXPORT extern const base::FeatureParam<bool>
-    kStorageAccessAPIGrantsUnpartitionedStorage;
-// Whether to auto-grant storage access requests when the top level origin and
-// the requesting origin are in the same First-Party Set.
-NET_EXPORT extern const base::FeatureParam<bool>
-    kStorageAccessAPIAutoGrantInFPS;
-// Whether to auto-deny storage access requests when the top level origin and
-// the requesting origin are not in the same First-Party Set.
-NET_EXPORT extern const base::FeatureParam<bool>
-    kStorageAccessAPIAutoDenyOutsideFPS;
-
 NET_EXPORT BASE_DECLARE_FEATURE(kThirdPartyStoragePartitioning);
 NET_EXPORT BASE_DECLARE_FEATURE(kSupportPartitionedBlobUrl);
 
