@@ -1026,4 +1026,4 @@ NET_ERROR(DNS_REQUEST_CANCELLED, -810)
 
 // The hostname resolution of HTTPS record was expected to be resolved with
 // alpn values of supported protocols, but did not.
-NET_ERROR(DNS_NO_MACHING_SUPPORTED_ALPN, -811)
+NET_ERROR(DNS_NO_MATCHING_SUPPORTED_ALPN, -811)
