@@ -82,13 +82,13 @@ enum class ParseIntError {
 // |optional_error| was non-null, then it is filled with the reason for the
 // failure.
 [[nodiscard]] NET_EXPORT bool ParseInt32(
-    const base::StringPiece& input,
+    base::StringPiece input,
     ParseIntFormat format,
     int32_t* output,
     ParseIntError* optional_error = nullptr);
 
 [[nodiscard]] NET_EXPORT bool ParseInt64(
-    const base::StringPiece& input,
+    base::StringPiece input,
     ParseIntFormat format,
     int64_t* output,
     ParseIntError* optional_error = nullptr);
@@ -98,12 +98,12 @@ enum class ParseIntError {
 // These are equivalent to calling ParseInt*() with a format string of
 // ParseIntFormat::NON_NEGATIVE and unsigned output types.
 [[nodiscard]] NET_EXPORT bool ParseUint32(
-    const base::StringPiece& input,
+    base::StringPiece input,
     uint32_t* output,
     ParseIntError* optional_error = nullptr);
 
 [[nodiscard]] NET_EXPORT bool ParseUint64(
-    const base::StringPiece& input,
+    base::StringPiece input,
     uint64_t* output,
     ParseIntError* optional_error = nullptr);
 
