@@ -4,8 +4,6 @@
 
 #include "net/cert/pki/signature_algorithm.h"
 
-#include "net/cert/pki/cert_error_params.h"
-#include "net/cert/pki/cert_errors.h"
 #include "net/der/input.h"
 #include "net/der/parse_values.h"
 #include "net/der/parser.h"
@@ -216,13 +214,15 @@ const uint8_t kOidMgf1[] = {0x2a, 0x86, 0x48, 0x86, 0xf7,
 absl::optional<SignatureAlgorithm> ParseRsaPss(const der::Input& params) {
   der::Parser parser(params);
   der::Parser params_parser;
-  if (!parser.ReadSequence(&params_parser))
+  if (!parser.ReadSequence(&params_parser)) {
     return absl::nullopt;
+  }
 
   // There shouldn't be anything after the sequence (by definition the
   // parameters is a single sequence).
-  if (parser.HasMore())
+  if (parser.HasMore()) {
     return absl::nullopt;
+  }
 
   // The default values for hashAlgorithm, maskGenAlgorithm, and saltLength
   // correspond to SHA-1, which we do not support with RSA-PSS, so treat them as
@@ -267,8 +267,6 @@ absl::optional<SignatureAlgorithm> ParseRsaPss(const der::Input& params) {
   return absl::nullopt;
 }
 
-DEFINE_CERT_ERROR_ID(kUnknownSignatureAlgorithm, "Unknown signature algorithm");
-
 }  // namespace
 
 [[nodiscard]] bool ParseAlgorithmIdentifier(const der::Input& input,
@@ -327,12 +325,12 @@ DEFINE_CERT_ERROR_ID(kUnknownSignatureAlgorithm, "Unknown signature algorithm");
 }
 
 absl::optional<SignatureAlgorithm> ParseSignatureAlgorithm(
-    const der::Input& algorithm_identifier,
-    CertErrors* errors) {
+    const der::Input& algorithm_identifier) {
   der::Input oid;
   der::Input params;
-  if (!ParseAlgorithmIdentifier(algorithm_identifier, &oid, &params))
+  if (!ParseAlgorithmIdentifier(algorithm_identifier, &oid, &params)) {
     return absl::nullopt;
+  }
 
   // TODO(eroman): Each OID is tested for equality in order, which is not
   // particularly efficient.
@@ -378,10 +376,6 @@ absl::optional<SignatureAlgorithm> ParseSignatureAlgorithm(
   }
 
   // Unknown signature algorithm.
-  if (errors) {
-    errors->AddError(kUnknownSignatureAlgorithm,
-                     CreateCertErrorParams2Der("oid", oid, "params", params));
-  }
   return absl::nullopt;
 }
 
