@@ -18,7 +18,6 @@
 #include <secport.h>
 #include <string.h>
 
-#include "base/compiler_specific.h"
 #include "base/logging.h"
 #include "base/strings/stringprintf.h"
 #include "crypto/nss_util.h"
@@ -439,19 +438,4 @@ SHA256HashValue CalculateFingerprint256(CERTCertificate* cert) {
   return sha256;
 }
 
-DISABLE_CFI_DLSYM
-SECStatus GetCertIsPerm(const CERTCertificate* cert, PRBool* isperm) {
-  // TODO(https://crbug.com/1365414): When the minimum NSS version is raised to
-  // 3.31 or higher, replace this with calling CERT_GetCertIsPerm directly.
-  using GetCertIsPermFunction = SECStatus (*)(const CERTCertificate*, PRBool*);
-  static GetCertIsPermFunction get_cert_is_perm =
-      reinterpret_cast<GetCertIsPermFunction>(
-          dlsym(RTLD_DEFAULT, "CERT_GetCertIsPerm"));
-  if (get_cert_is_perm) {
-    return get_cert_is_perm(cert, isperm);
-  }
-  *isperm = cert->isperm;
-  return SECSuccess;
-}
-
 }  // namespace net::x509_util
