@@ -670,9 +670,6 @@ std::unique_ptr<CanonicalCookie> CanonicalCookie::Create(
   UMA_HISTOGRAM_BOOLEAN("Cookie.DoubleUnderscorePrefixedName",
                         name_prefixed_with_underscores);
 
-  UMA_HISTOGRAM_BOOLEAN("Cookie.ControlCharacterTruncation",
-                        parsed_cookie.HasTruncatedNameOrValue());
-
   UMA_HISTOGRAM_ENUMERATION(
       "Cookie.TruncatingCharacterInCookieString",
       parsed_cookie.GetTruncatingCharacterInCookieStringType());
