@@ -9,9 +9,12 @@
 
 #include "base/files/file_util.h"
 #include "base/hash/hash.h"
+#include "base/metrics/histogram_macros.h"
 #include "base/numerics/safe_math.h"
 #include "base/strings/string_util.h"
 #include "base/time/time.h"
+#include "build/build_config.h"
+#include "net/base/features.h"
 #include "net/base/io_buffer.h"
 #include "net/base/net_errors.h"
 #include "net/disk_cache/blockfile/backend_impl.h"
@@ -355,7 +358,8 @@ int EntryImpl::WriteDataImpl(int index,
                              IOBuffer* buf,
                              int buf_len,
                              CompletionOnceCallback callback,
-                             bool truncate) {
+                             bool truncate,
+                             bool* optimistic) {
   if (net_log_.IsCapturing()) {
     NetLogReadWriteData(net_log_, net::NetLogEventType::ENTRY_WRITE_DATA,
                         net::NetLogEventPhase::BEGIN, index, offset, buf_len,
@@ -363,7 +367,7 @@ int EntryImpl::WriteDataImpl(int index,
   }
 
   int result = InternalWriteData(index, offset, buf, buf_len,
-                                 std::move(callback), truncate);
+                                 std::move(callback), truncate, optimistic);
 
   if (result != net::ERR_IO_PENDING && net_log_.IsCapturing()) {
     NetLogReadWriteComplete(net_log_, net::NetLogEventType::ENTRY_WRITE_DATA,
@@ -696,10 +700,12 @@ void EntryImpl::FixForDelete() {
 }
 
 void EntryImpl::IncrementIoCount() {
+  ++io_count_;
   backend_->IncrementIoCount();
 }
 
 void EntryImpl::DecrementIoCount() {
+  --io_count_;
   if (backend_.get())
     backend_->DecrementIoCount();
 }
@@ -872,9 +878,13 @@ int EntryImpl::WriteData(int index,
                          int buf_len,
                          CompletionOnceCallback callback,
                          bool truncate) {
-  if (callback.is_null())
-    return WriteDataImpl(index, offset, buf, buf_len, std::move(callback),
-                         truncate);
+  if (callback.is_null()) {
+    bool optimistic;
+    int err = WriteDataImpl(index, offset, buf, buf_len, std::move(callback),
+                            truncate, &optimistic);
+    DCHECK(!optimistic);
+    return err;
+  }
 
   DCHECK(node_.Data()->dirty || read_only_);
   if (index < 0 || index >= kNumStreams)
@@ -1113,9 +1123,11 @@ int EntryImpl::InternalWriteData(int index,
                                  IOBuffer* buf,
                                  int buf_len,
                                  CompletionOnceCallback callback,
-                                 bool truncate) {
+                                 bool truncate,
+                                 bool* optimistic) {
   DCHECK(node_.Data()->dirty || read_only_);
   DVLOG(2) << "Write to " << index << " at " << offset << " : " << buf_len;
+  *optimistic = false;
   if (index < 0 || index >= kNumStreams)
     return net::ERR_INVALID_ARGUMENT;
 
@@ -1154,6 +1166,8 @@ int EntryImpl::InternalWriteData(int index,
   backend_->OnEvent(Stats::WRITE_DATA);
   backend_->OnWrite(buf_len);
 
+  UMA_HISTOGRAM_BOOLEAN("HttpCache.BlockfileWriteInUserBuffer",
+                        !!user_buffers_[index].get());
   if (user_buffers_[index].get()) {
     // Complete the operation locally.
     user_buffers_[index]->Write(offset, buf, buf_len);
@@ -1186,17 +1200,32 @@ int EntryImpl::InternalWriteData(int index,
   if (!buf_len)
     return 0;
 
+  scoped_refptr<net::IOBuffer> op_buf = buf;
+
   SyncCallback* io_callback = nullptr;
   bool null_callback = callback.is_null();
   if (!null_callback) {
-    io_callback = new SyncCallback(this, buf, std::move(callback),
+#if BUILDFLAG(IS_WIN)
+    // Only do this optimization on Windows, since it's guaranteed there that an
+    // async write to the File object followed by a read will always give the
+    // previously written data. On Posix this isn't the case.
+    if (base::FeatureList::IsEnabled(
+            net::features::kOptimisticBlockfileWrite) &&
+        io_count_ == 0) {
+      op_buf = base::MakeRefCounted<IOBuffer>(buf_len);
+      memcpy(op_buf->data(), buf->data(), buf_len);
+      *optimistic = true;
+    }
+#endif
+
+    io_callback = new SyncCallback(this, op_buf.get(), std::move(callback),
                                    net::NetLogEventType::ENTRY_WRITE_DATA);
   }
 
   TimeTicks start_async = TimeTicks::Now();
 
   bool completed;
-  if (!file->Write(buf->data(), buf_len, file_offset, io_callback,
+  if (!file->Write(op_buf->data(), buf_len, file_offset, io_callback,
                    &completed)) {
     if (io_callback)
       io_callback->Discard();
@@ -1210,7 +1239,8 @@ int EntryImpl::InternalWriteData(int index,
     ReportIOTime(kWriteAsync1, start_async);
 
   ReportIOTime(kWrite, start);
-  return (completed || null_callback) ? buf_len : net::ERR_IO_PENDING;
+  return (completed || *optimistic || null_callback) ? buf_len
+                                                     : net::ERR_IO_PENDING;
 }
 
 // ------------------------------------------------------------------------
