@@ -10,8 +10,8 @@
 #include <limits>
 #include <utility>
 
-#include "base/bind.h"
 #include "base/check.h"
+#include "base/functional/bind.h"
 #include "base/location.h"
 #include "base/task/thread_pool.h"
 #include "net/base/net_errors.h"
