@@ -5,7 +5,7 @@
 #ifndef NET_DNS_DNS_CONFIG_WATCHER_MAC_H_
 #define NET_DNS_DNS_CONFIG_WATCHER_MAC_H_
 
-#include "base/callback_forward.h"
+#include "base/functional/callback_forward.h"
 #include "net/dns/notify_watcher_mac.h"
 
 namespace net::internal {
