@@ -12,11 +12,13 @@
 #include "base/containers/flat_set.h"
 #include "base/functional/function_ref.h"
 #include "base/metrics/histogram_macros.h"
+#include "base/ranges/algorithm.h"
 #include "base/timer/elapsed_timer.h"
 #include "base/types/optional_util.h"
 #include "net/base/schemeful_site.h"
 #include "net/first_party_sets/addition_overlaps_union_find.h"
 #include "net/first_party_sets/first_party_set_entry.h"
+#include "net/first_party_sets/first_party_set_entry_override.h"
 #include "net/first_party_sets/first_party_set_metadata.h"
 #include "net/first_party_sets/first_party_sets_context_config.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
@@ -52,7 +54,7 @@ FlattenedSets SetListToFlattenedSets(const std::vector<SingleSet>& set_list) {
 // from a site to its entry.
 void UpdateCustomizations(
     const std::vector<SingleSet>& set_list,
-    std::vector<std::pair<SchemefulSite, absl::optional<FirstPartySetEntry>>>&
+    std::vector<std::pair<SchemefulSite, FirstPartySetEntryOverride>>&
         site_to_entry) {
   for (const auto& set : set_list) {
     for (const auto& site_and_entry : set) {
@@ -62,7 +64,7 @@ void UpdateCustomizations(
 }
 
 const SchemefulSite& ProjectKey(
-    const std::pair<SchemefulSite, absl::optional<FirstPartySetEntry>>& p) {
+    const std::pair<SchemefulSite, FirstPartySetEntryOverride>& p) {
   return p.first;
 }
 
@@ -76,27 +78,36 @@ SamePartyContext::Type ContextTypeFromBool(bool is_same_party) {
 GlobalFirstPartySets::GlobalFirstPartySets() = default;
 
 GlobalFirstPartySets::GlobalFirstPartySets(
+    base::Version public_sets_version,
     base::flat_map<SchemefulSite, FirstPartySetEntry> entries,
     base::flat_map<SchemefulSite, SchemefulSite> aliases)
-    : GlobalFirstPartySets(std::move(entries),
-                           std::move(aliases),
-                           /*manual_sets=*/{},
-                           FirstPartySetsContextConfig()) {}
+    : GlobalFirstPartySets(
+          public_sets_version,
+          public_sets_version.IsValid()
+              ? std::move(entries)
+              : base::flat_map<SchemefulSite, FirstPartySetEntry>(),
+          public_sets_version.IsValid()
+              ? std::move(aliases)
+              : base::flat_map<SchemefulSite, SchemefulSite>(),
+          FirstPartySetsContextConfig()) {}
 
 GlobalFirstPartySets::GlobalFirstPartySets(
+    base::Version public_sets_version,
     base::flat_map<SchemefulSite, FirstPartySetEntry> entries,
     base::flat_map<SchemefulSite, SchemefulSite> aliases,
-    base::flat_map<SchemefulSite, FirstPartySetEntry> manual_sets,
     FirstPartySetsContextConfig manual_config)
-    : entries_(std::move(entries)),
+    : public_sets_version_(std::move(public_sets_version)),
+      entries_(std::move(entries)),
       aliases_(std::move(aliases)),
-      manual_sets_(std::move(manual_sets)),
       manual_config_(std::move(manual_config)) {
-  // `aliases_` can only be nonempty if `entries_` is also nonempty.
-  if (!aliases_.empty())
-    DCHECK(!entries_.empty());
-
-  DCHECK_EQ(manual_sets_.empty(), manual_config_.empty());
+  if (public_sets_version_.IsValid()) {
+    DCHECK(base::ranges::all_of(aliases_, [&](const auto& pair) {
+      return entries_.contains(pair.second);
+    }));
+  } else {
+    DCHECK(entries_.empty());
+    DCHECK(aliases_.empty());
+  }
 }
 
 GlobalFirstPartySets::GlobalFirstPartySets(GlobalFirstPartySets&&) = default;
@@ -106,8 +117,8 @@ GlobalFirstPartySets& GlobalFirstPartySets::operator=(GlobalFirstPartySets&&) =
 GlobalFirstPartySets::~GlobalFirstPartySets() = default;
 
 bool GlobalFirstPartySets::operator==(const GlobalFirstPartySets& other) const {
-  return std::tie(entries_, aliases_, manual_sets_, manual_config_) ==
-         std::tie(other.entries_, other.aliases_, other.manual_sets_,
+  return std::tie(public_sets_version_, entries_, aliases_, manual_config_) ==
+         std::tie(other.public_sets_version_, other.entries_, other.aliases_,
                   other.manual_config_);
 }
 
@@ -116,7 +127,7 @@ bool GlobalFirstPartySets::operator!=(const GlobalFirstPartySets& other) const {
 }
 
 GlobalFirstPartySets GlobalFirstPartySets::Clone() const {
-  return GlobalFirstPartySets(entries_, aliases_, manual_sets_,
+  return GlobalFirstPartySets(public_sets_version_, entries_, aliases_,
                               manual_config_.Clone());
 }
 
@@ -133,16 +144,19 @@ absl::optional<FirstPartySetEntry> GlobalFirstPartySets::FindEntry(
 
   // Check if `normalized_site` can be found in the customizations first.
   if (config) {
-    if (const auto entry = config->FindOverride(normalized_site);
-        entry.has_value()) {
-      return entry.value();
+    if (const auto override = config->FindOverride(normalized_site);
+        override.has_value()) {
+      return override->IsDeletion() ? absl::nullopt
+                                    : absl::make_optional(override->GetEntry());
     }
   }
 
   // Now see if it's in the manual config (with or without a manual alias).
-  if (const auto manual_entry = manual_config_.FindOverride(normalized_site);
-      manual_entry.has_value()) {
-    return manual_entry.value();
+  if (const auto manual_override = manual_config_.FindOverride(normalized_site);
+      manual_override.has_value()) {
+    return manual_override->IsDeletion()
+               ? absl::nullopt
+               : absl::make_optional(manual_override->GetEntry());
   }
 
   // Finally, look up in `entries_`, applying an alias if applicable.
@@ -225,18 +239,31 @@ bool GlobalFirstPartySets::IsContextSamePartyWithSite(
 void GlobalFirstPartySets::ApplyManuallySpecifiedSet(
     const base::flat_map<SchemefulSite, FirstPartySetEntry>& manual_entries) {
   DCHECK(manual_config_.empty());
-  manual_sets_ = manual_entries;
   // We handle the manually-specified set the same way as we handle
   // replacement enterprise policy sets.
   manual_config_ = ComputeConfig(
       /*replacement_sets=*/{manual_entries}, /*addition_sets=*/{});
 }
 
+void GlobalFirstPartySets::UnsafeSetManualConfig(
+    FirstPartySetsContextConfig manual_config) {
+  DCHECK(manual_config_.empty());
+  manual_config_ = std::move(manual_config);
+}
+
 FirstPartySetsContextConfig GlobalFirstPartySets::ComputeConfig(
     const std::vector<SingleSet>& replacement_sets,
     const std::vector<SingleSet>& addition_sets) const {
-  // Maps a site to its new entry if it has one.
-  std::vector<std::pair<SchemefulSite, absl::optional<FirstPartySetEntry>>>
+  if (base::ranges::all_of(replacement_sets,
+                           [](const SingleSet& set) { return set.empty(); }) &&
+      base::ranges::all_of(addition_sets,
+                           [](const SingleSet& set) { return set.empty(); })) {
+    // Nothing to do.
+    return FirstPartySetsContextConfig();
+  }
+
+  // Maps a site to its override.
+  std::vector<std::pair<SchemefulSite, FirstPartySetEntryOverride>>
       site_to_entry;
 
   std::vector<base::flat_map<SchemefulSite, FirstPartySetEntry>>
@@ -268,13 +295,12 @@ FirstPartySetsContextConfig GlobalFirstPartySets::ComputeConfig(
   for (const auto& [member, set_entry] : flattened_replacements) {
     if (member == set_entry.primary())
       continue;
-    if (auto existing_entry = FindEntry(member, /*config=*/nullptr);
-        existing_entry.has_value() && existing_entry->primary() != member) {
-      if (!addition_intersected_owners.contains(existing_entry->primary()) &&
-          !flattened_additions.contains(existing_entry->primary()) &&
-          !flattened_replacements.contains(existing_entry->primary())) {
-        potential_singletons[existing_entry->primary()].insert(member);
-      }
+    if (const auto existing_entry = FindEntry(member, /*config=*/nullptr);
+        existing_entry.has_value() && existing_entry->primary() != member &&
+        !addition_intersected_owners.contains(existing_entry->primary()) &&
+        !flattened_additions.contains(existing_entry->primary()) &&
+        !flattened_replacements.contains(existing_entry->primary())) {
+      potential_singletons[existing_entry->primary()].insert(member);
     }
   }
 
@@ -291,48 +317,53 @@ FirstPartySetsContextConfig GlobalFirstPartySets::ComputeConfig(
     }
   }
 
-  // Find out which potential singletons are actually singletons; delete
-  // members whose owners left; and reparent the sets that intersected with
-  // an addition set.
-  // Note: use a null config here, to avoid taking unrelated policy sets into
-  // account.
-  ForEachEffectiveSetEntry(/*config=*/nullptr, [&](const SchemefulSite& member,
-                                                   const FirstPartySetEntry&
-                                                       set_entry) {
-    // Reparent all sites in any intersecting addition sets.
-    if (auto entry = addition_intersected_owners.find(set_entry.primary());
-        entry != addition_intersected_owners.end() &&
-        !flattened_replacements.contains(member)) {
-      site_to_entry.emplace_back(
-          member, FirstPartySetEntry(entry->second.primary(),
-                                     member == entry->second.primary()
-                                         ? SiteType::kPrimary
-                                         : SiteType::kAssociated,
-                                     absl::nullopt));
-    }
-    if (member == set_entry.primary())
-      return true;
-    // Remove non-singletons from the potential list.
-    if (auto entry = potential_singletons.find(set_entry.primary());
-        entry != potential_singletons.end() &&
-        !entry->second.contains(member)) {
-      // This owner lost members, but it still has at least one (`member`),
-      // so it's not a singleton.
-      potential_singletons.erase(entry);
-    }
-    // Remove members from sets whose owner left.
-    if (replaced_existing_owners.contains(set_entry.primary()) &&
-        !flattened_replacements.contains(member) &&
-        !addition_intersected_owners.contains(set_entry.primary())) {
-      site_to_entry.emplace_back(member, absl::nullopt);
-    }
+  if (!addition_intersected_owners.empty() || !potential_singletons.empty() ||
+      !replaced_existing_owners.empty()) {
+    // Find out which potential singletons are actually singletons; delete
+    // members whose owners left; and reparent the sets that intersected with
+    // an addition set.
+    // Note: use a null config here, to avoid taking unrelated policy sets into
+    // account.
+    ForEachEffectiveSetEntry(
+        /*config=*/nullptr,
+        [&](const SchemefulSite& member, const FirstPartySetEntry& set_entry) {
+          // Reparent all sites in any intersecting addition sets.
+          if (const auto entry =
+                  addition_intersected_owners.find(set_entry.primary());
+              entry != addition_intersected_owners.end() &&
+              !flattened_replacements.contains(member)) {
+            site_to_entry.emplace_back(
+                member, FirstPartySetEntry(entry->second.primary(),
+                                           member == entry->second.primary()
+                                               ? SiteType::kPrimary
+                                               : SiteType::kAssociated,
+                                           absl::nullopt));
+          }
+          if (member == set_entry.primary())
+            return true;
+          // Remove non-singletons from the potential list.
+          if (const auto entry = potential_singletons.find(set_entry.primary());
+              entry != potential_singletons.end() &&
+              !entry->second.contains(member)) {
+            // This owner lost members, but it still has at least one
+            // (`member`), so it's not a singleton.
+            potential_singletons.erase(entry);
+          }
+          // Remove members from sets whose owner left.
+          if (replaced_existing_owners.contains(set_entry.primary()) &&
+              !flattened_replacements.contains(member) &&
+              !addition_intersected_owners.contains(set_entry.primary())) {
+            site_to_entry.emplace_back(member, FirstPartySetEntryOverride());
+          }
 
-    return true;
-  });
-  // Any owner remaining in `potential_singleton` is a real singleton, so delete
-  // it:
-  for (auto& [owner, members] : potential_singletons) {
-    site_to_entry.emplace_back(owner, absl::nullopt);
+          return true;
+        });
+
+    // Any owner remaining in `potential_singleton` is a real singleton, so
+    // delete it:
+    for (const auto& [owner, members] : potential_singletons) {
+      site_to_entry.emplace_back(owner, FirstPartySetEntryOverride());
+    }
   }
 
   // For every public alias that would now refer to a site in the overlay, which
@@ -340,7 +371,7 @@ FirstPartySetsContextConfig GlobalFirstPartySets::ComputeConfig(
   for (const auto& [alias, site] : aliases_) {
     if (base::Contains(site_to_entry, site, ProjectKey) &&
         !base::Contains(site_to_entry, alias, ProjectKey)) {
-      site_to_entry.emplace_back(alias, absl::nullopt);
+      site_to_entry.emplace_back(alias, FirstPartySetEntryOverride());
     }
   }
 
@@ -351,11 +382,18 @@ std::vector<base::flat_map<SchemefulSite, FirstPartySetEntry>>
 GlobalFirstPartySets::NormalizeAdditionSets(
     const std::vector<base::flat_map<SchemefulSite, FirstPartySetEntry>>&
         addition_sets) const {
+  if (base::ranges::all_of(addition_sets,
+                           [](const SingleSet& set) { return set.empty(); })) {
+    // Nothing to do.
+    return {};
+  }
+
   // Find all the addition sets that intersect with any given public set.
   base::flat_map<SchemefulSite, base::flat_set<size_t>> addition_set_overlaps;
   for (size_t set_idx = 0; set_idx < addition_sets.size(); set_idx++) {
     for (const auto& site_and_entry : addition_sets[set_idx]) {
-      if (auto entry = FindEntry(site_and_entry.first, /*config=*/nullptr);
+      if (const auto entry =
+              FindEntry(site_and_entry.first, /*config=*/nullptr);
           entry.has_value()) {
         addition_set_overlaps[entry->primary()].insert(set_idx);
       }
@@ -364,7 +402,8 @@ GlobalFirstPartySets::NormalizeAdditionSets(
 
   // Union together all transitively-overlapping addition sets.
   AdditionOverlapsUnionFind union_finder(addition_sets.size());
-  for (auto& [public_site, addition_set_indices] : addition_set_overlaps) {
+  for (const auto& [public_site, addition_set_indices] :
+       addition_set_overlaps) {
     for (size_t representative : addition_set_indices) {
       union_finder.Union(*addition_set_indices.begin(), representative);
     }
@@ -372,7 +411,7 @@ GlobalFirstPartySets::NormalizeAdditionSets(
 
   // Now build the new addition sets, with all transitive overlaps eliminated.
   std::vector<SingleSet> normalized_additions;
-  for (auto& [rep, children] : union_finder.SetsMapping()) {
+  for (const auto& [rep, children] : union_finder.SetsMapping()) {
     SingleSet normalized = addition_sets[rep];
     const SchemefulSite& rep_primary =
         addition_sets[rep].begin()->second.primary();
@@ -408,6 +447,12 @@ bool GlobalFirstPartySets::ForEachPublicSetEntry(
   return true;
 }
 
+bool GlobalFirstPartySets::ForEachManualConfigEntry(
+    base::FunctionRef<bool(const SchemefulSite&,
+                           const FirstPartySetEntryOverride&)> f) const {
+  return manual_config_.ForEachCustomizationEntry(f);
+}
+
 bool GlobalFirstPartySets::ForEachEffectiveSetEntry(
     const FirstPartySetsContextConfig& config,
     base::FunctionRef<bool(const SchemefulSite&, const FirstPartySetEntry&)> f)
@@ -423,9 +468,9 @@ bool GlobalFirstPartySets::ForEachEffectiveSetEntry(
   if (config != nullptr) {
     if (!config->ForEachCustomizationEntry(
             [&](const SchemefulSite& site,
-                const absl::optional<FirstPartySetEntry>& maybe_entry) {
-              if (maybe_entry.has_value())
-                return f(site, *maybe_entry);
+                const FirstPartySetEntryOverride& override) {
+              if (!override.IsDeletion())
+                return f(site, override.GetEntry());
               return true;
             })) {
       return false;
@@ -435,9 +480,9 @@ bool GlobalFirstPartySets::ForEachEffectiveSetEntry(
   // Then the manual set:
   if (!manual_config_.ForEachCustomizationEntry(
           [&](const SchemefulSite& site,
-              const absl::optional<FirstPartySetEntry>& maybe_entry) {
-            if (maybe_entry.has_value() && (!config || !config->Contains(site)))
-              return f(site, *maybe_entry);
+              const FirstPartySetEntryOverride& override) {
+            if (!override.IsDeletion() && (!config || !config->Contains(site)))
+              return f(site, override.GetEntry());
             return true;
           })) {
     return false;
@@ -454,23 +499,18 @@ bool GlobalFirstPartySets::ForEachEffectiveSetEntry(
 
 std::ostream& operator<<(std::ostream& os, const GlobalFirstPartySets& sets) {
   os << "{entries = {";
-  for (const auto& [site, entry] : sets.entries()) {
+  for (const auto& [site, entry] : sets.entries_) {
     os << "{" << site.Serialize() << ": " << entry << "}, ";
   }
   os << "}, aliases = {";
-  for (const auto& [alias, canonical] : sets.aliases()) {
+  for (const auto& [alias, canonical] : sets.aliases_) {
     os << "{" << alias.Serialize() << ": " << canonical.Serialize() << "}, ";
   }
-  os << "}, manual_sets = {";
-  for (const auto& [site, entry] : sets.manual_sets()) {
-    os << "{" << site.Serialize() << ": " << entry << "}, ";
-  }
   os << "}, manual_config = {";
-  sets.manual_config().ForEachCustomizationEntry(
+  sets.ForEachManualConfigEntry(
       [&](const net::SchemefulSite& site,
-          const absl::optional<net::FirstPartySetEntry>& maybe_entry) {
-        os << "{" << site.Serialize() << ": ";
-        maybe_entry.has_value() ? os << maybe_entry.value() : os << "nullopt";
+          const FirstPartySetEntryOverride& override) {
+        os << "{" << site.Serialize() << ": " << override << "},";
         return true;
       });
   os << "}}";
