@@ -4,8 +4,8 @@
 
 #include "net/proxy_resolution/win/dhcp_pac_file_adapter_fetcher_win.h"
 
-#include "base/bind.h"
-#include "base/callback_helpers.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback_helpers.h"
 #include "base/location.h"
 #include "base/logging.h"
 #include "base/memory/free_deleter.h"
