@@ -46,7 +46,6 @@
 
 #if BUILDFLAG(IS_ANDROID)
 #include "net/android/network_library.h"
-#include "net/android/radio_activity_tracker.h"
 #endif  // BUILDFLAG(IS_ANDROID)
 
 // If we don't have a definition for TCPI_OPT_SYN_DATA, create one.
@@ -340,10 +339,6 @@ int TCPSocketPosix::Write(
   DCHECK(socket_);
   DCHECK(!callback.is_null());
 
-#if BUILDFLAG(IS_ANDROID)
-  android::MaybeRecordTCPWriteForWakeupTrigger(traffic_annotation);
-#endif  // BUILDFLAG(IS_ANDROID)
-
   CompletionOnceCallback write_callback = base::BindOnce(
       &TCPSocketPosix::WriteCompleted,
       // Grab a reference to |buf| so that WriteCompleted() can still
