@@ -88,10 +88,6 @@ void TestSSLPrivateKeyMatches(SSLPrivateKey* key, const std::string& pkcs8) {
   // Test all supported algorithms.
   std::vector<uint16_t> preferences = key->GetAlgorithmPreferences();
 
-  // To support TLS 1.1 and earlier, RSA keys must implicitly support MD5-SHA1,
-  // despite not being advertised.
-  preferences.push_back(SSL_SIGN_RSA_PKCS1_MD5_SHA1);
-
   for (uint16_t algorithm : preferences) {
     SCOPED_TRACE(
         SSL_get_signature_algorithm_name(algorithm, 0 /* exclude curve */));
