@@ -122,6 +122,12 @@ class CertBuilder {
       base::StringPiece common_name,
       unsigned common_name_tag);
 
+  // Set the version of the certificate. Note that only V3 certificates may
+  // contain extensions, so if |version| is |V1| or |V2| you may want to also
+  // call |ClearExtensions()| unless you intentionally want to generate an
+  // invalid certificate.
+  void SetCertificateVersion(CertificateVersion version);
+
   // Sets a value for the indicated X.509 (v3) extension.
   void SetExtension(const der::Input& oid,
                     std::string value,
@@ -130,6 +136,9 @@ class CertBuilder {
   // Removes an extension (if present).
   void EraseExtension(const der::Input& oid);
 
+  // Removes all extensions.
+  void ClearExtensions();
+
   // Sets the basicConstraints extension. |path_len| may be negative to
   // indicate the pathLenConstraint should be omitted.
   void SetBasicConstraints(bool is_ca, int path_len);
@@ -320,6 +329,11 @@ class CertBuilder {
   // created.
   std::string GetPEMFullChain();
 
+  // Returns the private key as PEM.
+  // Convenience method for debugging, to more easily log what certs are being
+  // created.
+  std::string GetPrivateKeyPEM();
+
  private:
   // Initializes the CertBuilder, if |orig_cert| is non-null it will be used as
   // a template. If |issuer| is null then the generated certificate will be
@@ -369,6 +383,7 @@ class CertBuilder {
     std::string value;
   };
 
+  CertificateVersion version_ = CertificateVersion::V3;
   std::string validity_tlv_;
   absl::optional<std::string> issuer_tlv_;
   std::string subject_tlv_;
