@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright 2011 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,14 +6,9 @@
 
 #include <memory>
 
-#include "base/base_paths.h"
 #include "base/command_line.h"
 #include "base/environment.h"
 #include "base/files/file_path.h"
-#include "base/files/file_util.h"
-#include "base/logging.h"
-#include "base/path_service.h"
-#include "base/process/launch.h"
 #include "build/build_config.h"
 
 namespace {
@@ -45,23 +40,6 @@ void SetPythonPathInEnvironment(const std::vector<base::FilePath>& python_path,
   (*map)[kVPythonClearPathEnv] = base::NativeEnvironmentString();
 }
 
-bool GetPythonCommand(base::CommandLine* python_cmd) {
-  DCHECK(python_cmd);
-
-// Use vpython to pick up src.git's vpython VirtualEnv spec.
-#if BUILDFLAG(IS_WIN)
-  python_cmd->SetProgram(base::FilePath(FILE_PATH_LITERAL("vpython.bat")));
-#else
-  python_cmd->SetProgram(base::FilePath(FILE_PATH_LITERAL("vpython")));
-#endif
-
-  // Launch python in unbuffered mode, so that python output doesn't mix with
-  // gtest output in buildbot log files. See http://crbug.com/147368.
-  python_cmd->AppendArg("-u");
-
-  return true;
-}
-
 bool GetPython3Command(base::CommandLine* python_cmd) {
   DCHECK(python_cmd);
 
