@@ -8,12 +8,12 @@
 #include <cstring>
 #include <utility>
 
-#include "base/bind.h"
-#include "base/callback_helpers.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback_helpers.h"
 #include "base/logging.h"
 #include "base/rand_util.h"
 #include "base/strings/strcat.h"
-#include "base/threading/thread_task_runner_handle.h"
+#include "base/task/single_thread_task_runner.h"
 #include "base/time/time.h"
 #include "build/build_config.h"
 #include "net/base/io_buffer.h"
@@ -561,7 +561,7 @@ void NaiveConnection::OnPushComplete(Direction from, Direction to, int result) {
     bytes_passed_without_yielding_[from] = 0;
     yield_after_time_[from] =
         time_func_() + base::Milliseconds(kYieldAfterDurationMilliseconds);
-    base::ThreadTaskRunnerHandle::Get()->PostTask(
+    base::SingleThreadTaskRunner::GetCurrentDefault()->PostTask(
         FROM_HERE,
         base::BindRepeating(&NaiveConnection::Pull,
                             weak_ptr_factory_.GetWeakPtr(), from, to));
