@@ -29,7 +29,7 @@ class StreamSocket;
 struct NetworkTrafficAnnotationTag;
 struct SSLConfig;
 class RedirectResolver;
-class NetworkIsolationKey;
+class NetworkAnonymizationKey;
 
 class NaiveConnection {
  public:
@@ -44,7 +44,7 @@ class NaiveConnection {
       const SSLConfig& proxy_ssl_config,
       RedirectResolver* resolver,
       HttpNetworkSession* session,
-      const NetworkIsolationKey& network_isolation_key,
+      const NetworkAnonymizationKey& network_anonymization_key,
       const NetLogWithSource& net_log,
       std::unique_ptr<StreamSocket> accepted_socket,
       const NetworkTrafficAnnotationTag& traffic_annotation);
@@ -99,7 +99,7 @@ class NaiveConnection {
   const SSLConfig& proxy_ssl_config_;
   RedirectResolver* resolver_;
   HttpNetworkSession* session_;
-  const NetworkIsolationKey& network_isolation_key_;
+  const NetworkAnonymizationKey& network_anonymization_key_;
   const NetLogWithSource& net_log_;
 
   CompletionRepeatingCallback io_callback_;
