@@ -7,10 +7,10 @@
 
 #include <utility>
 
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "base/location.h"
 #include "base/logging.h"
-#include "base/threading/thread_task_runner_handle.h"
+#include "base/task/single_thread_task_runner.h"
 #include "net/base/load_flags.h"
 #include "net/base/net_errors.h"
 #include "net/http/http_network_session.h"
@@ -70,13 +70,14 @@ NaiveProxy::NaiveProxy(std::unique_ptr<ServerSocket> listen_socket,
   server_ssl_config_.early_data_enabled = session_->params().enable_early_data;
 
   for (int i = 0; i < concurrency_; i++) {
-    network_anonymization_keys_.push_back(NetworkAnonymizationKey::CreateTransient());
+    network_anonymization_keys_.push_back(
+        NetworkAnonymizationKey::CreateTransient());
   }
 
   DCHECK(listen_socket_);
   // Start accepting connections in next run loop in case when delegate is not
   // ready to get callbacks.
-  base::ThreadTaskRunnerHandle::Get()->PostTask(
+  base::SingleThreadTaskRunner::GetCurrentDefault()->PostTask(
       FROM_HERE, base::BindOnce(&NaiveProxy::DoAcceptLoop,
                                 weak_ptr_factory_.GetWeakPtr()));
 }
@@ -196,8 +197,8 @@ void NaiveProxy::Close(unsigned int connection_id, int reason) {
   // connection. Instead of referencing connection with ID all the time,
   // destroys the connection in next run loop to make sure any pending
   // callbacks in the call stack return.
-  base::ThreadTaskRunnerHandle::Get()->DeleteSoon(FROM_HERE,
-                                                  std::move(it->second));
+  base::SingleThreadTaskRunner::GetCurrentDefault()->DeleteSoon(
+      FROM_HERE, std::move(it->second));
   connection_by_id_.erase(it);
 }
 
