@@ -353,6 +353,10 @@ class NET_EXPORT URLRequestJob {
   // On return, |this| may be deleted.
   void ReadRawDataComplete(int bytes_read);
 
+  const absl::optional<net::SchemefulSite>& request_initiator_site() const {
+    return request_initiator_site_;
+  }
+
   // The request that initiated this job. This value will never be nullptr.
   const raw_ptr<URLRequest> request_;
 
@@ -439,6 +443,11 @@ class NET_EXPORT URLRequestJob {
   // checks are performed, so this field must not be modified.
   absl::optional<RedirectInfo> deferred_redirect_info_;
 
+  // The request's initiator never changes, so we store it in format of
+  // SchemefulSite so that we don't recompute (including looking up the
+  // registrable domain) it during every redirect.
+  absl::optional<net::SchemefulSite> request_initiator_site_;
+
   // Non-null if ReadRawData() returned ERR_IO_PENDING, and the read has not
   // completed.
   CompletionOnceCallback read_raw_callback_;
