@@ -1,21 +1,18 @@
 #!/usr/bin/env python3
-# Copyright (c) 2012 The Chromium Authors. All rights reserved.
+# Copyright 2012 The Chromium Authors
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
 """Unittest for c_format.py.
 """
 
-from __future__ import print_function
-
+import io
 import os
 import sys
-if __name__ == '__main__':
-  sys.path.append(os.path.join(os.path.dirname(__file__), '../..'))
-
 import unittest
 
-from six import StringIO
+if __name__ == '__main__':
+  sys.path.append(os.path.join(os.path.dirname(__file__), '../..'))
 
 from grit import util
 from grit.tool import build
@@ -24,7 +21,7 @@ from grit.tool import build
 class CFormatUnittest(unittest.TestCase):
 
   def testMessages(self):
-    root = util.ParseGrdForUnittest(u"""
+    root = util.ParseGrdForUnittest("""
     <messages>
       <message name="IDS_QUESTIONS">Do you want to play questions?</message>
       <message name="IDS_QUOTES">
@@ -41,10 +38,10 @@ Statement.  Two all.  Game point.
     </messages>
       """)
 
-    buf = StringIO()
+    buf = io.StringIO()
     build.RcBuilder.ProcessNode(root, DummyOutput('c_format', 'en'), buf)
     output = util.StripBlankLinesAndComments(buf.getvalue())
-    self.assertEqual(u"""\
+    self.assertEqual("""\
 #include "resource.h"
 const char* GetString(int id) {
   switch (id) {
@@ -62,7 +59,7 @@ const char* GetString(int id) {
 }""", output)
 
 
-class DummyOutput(object):
+class DummyOutput:
 
   def __init__(self, type, language):
     self.type = type
